==> gitlab_dart-0.1.0.tar.gz: lib/src/models/projects.dart <==
part of gitlab_dart;

class License {
  String key;
  String name;
  String nickname;
  String htmlURL;
  String sourceURL;

  License({this.key, this.name, this.nickname, this.htmlURL, this.sourceURL});

  License.fromJSON(Map<String, dynamic> data)
      : key = data['key'],
        name = data['name'],
        nickname = data['nickname'],
        htmlURL = data['html_url'],
        sourceURL = data['source_url'];
}

class ProjectUserRelation {
  ProjectUser user;
  String state;

  int get ID => user.ID;
  String get username => user.username;
  String get name => user.name;
  String get avaterURL => user.avatarURL;
  String get webURL => user.webURL;

  ProjectUserRelation({this.user, this.state});

  ProjectUserRelation.fromJSON(Map<String, dynamic> data)
      : user = new ProjectUser.fromJSON(data),
        state = data['state'];
}

class Owner {
  // TODO: May have to move somewhere else;

  int ID;
  String name;
  DateTime createdAt;

  Owner({this.ID, this.name, this.createdAt});

  Owner.fromJSON(Map<String, dynamic> data)
      : ID = data['id'],
        name = data['name'],
        createdAt = DateTime.parse(data['created_at']);
}

class Group {
  int ID;
  String name;
  String fullPath;

  Group({this.ID, this.name, this.fullPath});

  Group.fromJSON(Map<String, dynamic> data, [prefix = ''])
      : ID = data['${prefix}_id'],
        name = data['${prefix}_name'],
        fullPath = data['${prefix}_full_path'];
}

class GroupAccess {
  Group group;
  int accessLevel;

  int get ID => group.ID;
  String get name => group.name;
  String get fullPath => group.fullPath;

  GroupAccess({this.group, this.accessLevel});

  GroupAccess.fromJSON(Map<String, dynamic> data)
      : group = new Group.fromJSON(data, 'group'),
        accessLevel = data['group_access_level'];
}

class Namespace {
  int ID;
  String name;
  String path;
  String kind;
  String fullPath;

  Namespace({this.ID, this.name, this.path, this.kind, this.fullPath});

  Namespace.fromJSON(Map<String, dynamic> data)
      : ID = data['id'],
        name = data['name'],
        path = data['path'],
        kind = data['kind'],
        fullPath = data['full_path'];
}

class ProjectLinks {
  String self;
  String issues;
  String mergeRequests;
  String repoBranches;
  String labels;
  String events;
  String members;

  ProjectLinks(
      {this.self,
      this.issues,
      this.mergeRequests,
      this.repoBranches,
      this.events,
      this.labels,
      this.members});

  ProjectLinks.fromJSON(Map<String, dynamic> data)
      : self = data['self'],
        issues = data['issues'],
        mergeRequests = data['merge_requests'],
        repoBranches = data['repo_branches'],
        labels = data['labels'],
        events = data['events'],
        members = data['members'];
}

class ProjectStatistics {
  int commits;
  int storageSize;
  int repositorySize;
  int wikiSize;
  int LFSObjectsSize;
  int jobArtifactsSize;
  int packagesSize;

  ProjectStatistics(
      {this.commits,
      this.storageSize,
      this.repositorySize,
      this.wikiSize,
      this.LFSObjectsSize,
      this.jobArtifactsSize,
      this.packagesSize});

  ProjectStatistics.fromJSON(Map<String, dynamic> data)
      : commits = data['commit_count'],
        storageSize = data['storage_size'],
        repositorySize = data['repository_size'],
        wikiSize = data['wiki_size'],
        LFSObjectsSize = data['lfs_objects_size'],
        jobArtifactsSize = data['job_artifacts_size'],
        packagesSize = data['packages_size'];
}

class AccessPermission {
  int accessLevel;
  int notificationLevel;

  AccessPermission({this.accessLevel, this.notificationLevel});

  AccessPermission.fromJSON(Map<String, dynamic> data)
      : accessLevel = data['access_level'],
        notificationLevel = data['notification_level'];
}

class ProjectPermission {
  AccessPermission projectAccess;
  AccessPermission groupAccess;

  ProjectPermission({this.projectAccess, this.groupAccess});

  ProjectPermission.fromJSON(Map<String, dynamic> data)
      : projectAccess = new AccessPermission.fromJSON(data['project_access']),
        groupAccess = new AccessPermission.fromJSON(data['group_access']);
}

class Project {
  bool simple; // Set by APIClient

  // Simple Fields
  int ID;
  String description;
  String defaultBranch;
  String sshURL;
  String httpURL;
  String webURL;
  String readmeURL;
  List<String> tagList;
  String name;
  String nameWithNamespace;
  String path;
  String pathWithNamespace;
  DateTime createdAt;
  DateTime lastActivityAt;
  int forks;
  int stars;
  String avatarURL;

  // Deep Fields;
  Owner owner;
  bool issueEnabled;
  int openIssues;
  bool mergeRequestEnabled;
  bool jobEnabled;
  bool wikiEnabled;
  bool snippetEnabled;
  bool resolveOutdatedDiffDiscussions;
  bool containerRegistryEnabled;
  int creatorID;
  Namespace namespace;
  String importStatus;
  String importError;
  bool sharedRunnerEnabled;
  String runnersToken;
  int CIdefaultGitDepth;
  bool publicJobs;
  List<GroupAccess> sharedWithGroup;
  bool onlyAllowMergeIfPiplineSucceeds;
  bool onlyAllowMergeIfAllDiscussionsAreResolved;
  bool requestAccessEnabled;
  String mergeMethod;
  ProjectStatistics statistics;
  ProjectPermission permissions;
  int approvalsBeforeMerge;
  Project forkedFromProject;

  // Available in details only
  String licenseURL;
  License license;
  String repositoryStorage;

  Project(this.name, this.path,
      {this.ID,
      this.description,
      this.defaultBranch,
      this.sshURL,
      this.httpURL,
      this.webURL,
      this.readmeURL,
      this.tagList,
      this.nameWithNamespace,
      this.pathWithNamespace,
      this.createdAt,
      this.lastActivityAt,
      this.forkedFromProject,
      this.forks,
      this.approvalsBeforeMerge,
      this.avatarURL,
      this.CIdefaultGitDepth,
      this.containerRegistryEnabled,
      this.creatorID,
      this.importError,
      this.importStatus,
      this.issueEnabled,
      this.jobEnabled,
      this.mergeMethod,
      this.mergeRequestEnabled,
      this.namespace,
      this.onlyAllowMergeIfAllDiscussionsAreResolved,
      this.onlyAllowMergeIfPiplineSucceeds,
      this.openIssues,
      this.owner,
      this.permissions,
      this.publicJobs,
      this.requestAccessEnabled,
      this.resolveOutdatedDiffDiscussions,
      this.runnersToken,
      this.sharedRunnerEnabled,
      this.sharedWithGroup,
      this.simple,
      this.snippetEnabled,
      this.stars,
      this.statistics,
      this.wikiEnabled});

  Project.fromJSON(Map<String, dynamic> data, [this.simple = true]) {
    ID = data['id'];
    description = data['description'];
    defaultBranch = data['default_branch'];
    sshURL = data['ssh_url'];
    webURL = data['web_url'];
    readmeURL = data['readme_url'];
    tagList = List<String>.from(data['tag_list']);
    name = data['name'];
    nameWithNamespace = data['name_with_namespace'];
    path = data['path'];
    pathWithNamespace = data['path_with_namespace'];
    createdAt = DateTime.parse(data['created_at']);
    lastActivityAt = DateTime.parse(data['last_activity_at']);
    forks = data['fork_count'];
    stars = data['star_count'];
    avatarURL = data['avatarURL'];
    if (!this.simple) {
      owner = new Owner.fromJSON(data['owner']);
      issueEnabled = data['issue_enabled'];
      openIssues = data['openIssues'];
      mergeRequestEnabled = data['merge_request_enabled'];
      jobEnabled = data['job_enabled'];
      wikiEnabled = data['wiki_enabled'];
      snippetEnabled = data['snippet_enabled'];
      resolveOutdatedDiffDiscussions =
          data['resolve_outdated_diff_discussions'];
      containerRegistryEnabled = data['container_registry_enabled'];
      creatorID = data['creator_id'];
      namespace = new Namespace.fromJSON(data['namespace']);
      importStatus = data['import_status'];
      importError = data['import_error'];
      sharedRunnerEnabled = data['shared_runner_enabled'];
      runnersToken = data['runners_token'];
      CIdefaultGitDepth = data['ci_default_git_depth'];
      publicJobs = data['public_jobs'];
      sharedWithGroup = List<GroupAccess>.of(
          (data['shared_with_group'] as Iterable)
              .map((item) => new GroupAccess.fromJSON(item)));
      onlyAllowMergeIfAllDiscussionsAreResolved =
          data['only_allow_merge_if_all_discussions_are_resolved'];
      onlyAllowMergeIfPiplineSucceeds =
          data['only_allow_merge_if_pipeline_succeeds'];
      requestAccessEnabled = data['request_access_enabled'];
      mergeMethod = data['merge_method'];
      statistics = new ProjectStatistics.fromJSON(data['statistics']);
      permissions = new ProjectPermission.fromJSON(data['permissions']);
      approvalsBeforeMerge = data['approvals_before_merege'];
      forkedFromProject = data['forked_from_prject'] ??
          new Project.fromJSON(data['forked_from_project'], true);
      licenseURL = data['license_url'];
      license = new License.fromJSON(data['license']);
      repositoryStorage = data['repository_storage'];
    }
  }
}

==> gitlab_dart-0.1.1.tar.gz: lib/src/models/projects.dart <==
part of gitlab_dart;

class License {
  String key;
  String name;
  String nickname;
  String htmlURL;
  String sourceURL;

  License({this.key, this.name, this.nickname, this.htmlURL, this.sourceURL});

  License.fromJSON(Map<String, dynamic> data)
      : key = data['key'],
        name = data['name'],
        nickname = data['nickname'],
        htmlURL = data['html_url'],
        sourceURL = data['source_url'];
}

class ProjectUserRelation {
  ProjectUser user;
  String state;

  int get id => user.id;
  String get username => user.username;
  String get name => user.name;
  String get avaterURL => user.avatarURL;
  String get webURL => user.webURL;

  ProjectUserRelation({this.user, this.state});

  ProjectUserRelation.fromJSON(Map<String, dynamic> data)
      : user = new ProjectUser.fromJSON(data),
        state = data['state'];
}

class Owner {
  // TODO: May have to move somewhere else;

  int id;
  String name;
  DateTime createdAt;

  Owner({this.id, this.name, this.createdAt});

  Owner.fromJSON(Map<String, dynamic> data)
      : id = data['id'],
        name = data['name'],
        createdAt = DateTime.parse(data['created_at']);
}

class Group {
  int id;
  String name;
  String fullPath;

  Group({this.id, this.name, this.fullPath});

  Group.fromJSON(Map<String, dynamic> data, [prefix = ''])
      : id = data['${prefix}_id'],
        name = data['${prefix}_name'],
        fullPath = data['${prefix}_full_path'];
}

class GroupAccess {
  Group group;
  int accessLevel;

  int get id => group.id;
  String get name => group.name;
  String get fullPath => group.fullPath;

  GroupAccess({this.group, this.accessLevel});

  GroupAccess.fromJSON(Map<String, dynamic> data)
      : group = new Group.fromJSON(data, 'group'),
        accessLevel = data['group_access_level'];
}

class Namespace {
  int id;
  String name;
  String path;
  String kind;
  String fullPath;

  Namespace({this.id, this.name, this.path, this.kind, this.fullPath});

  Namespace.fromJSON(Map<String, dynamic> data)
      : id = data['id'],
        name = data['name'],
        path = data['path'],
        kind = data['kind'],
        fullPath = data['full_path'];
}

class ProjectLinks {
  String self;
  String issues;
  String mergeRequests;
  String repoBranches;
  String labels;
  String events;
  String members;

  ProjectLinks(
      {this.self,
      this.issues,
      this.mergeRequests,
      this.repoBranches,
      this.events,
      this.labels,
      this.members});

  ProjectLinks.fromJSON(Map<String, dynamic> data)
      : self = data['self'],
        issues = data['issues'],
        mergeRequests = data['merge_requests'],
        repoBranches = data['repo_branches'],
        labels = data['labels'],
        events = data['events'],
        members = data['members'];
}

class ProjectStatistics {
  int commits;
  int storageSize;
  int repositorySize;
  int wikiSize;
  int lfsObjectsSize;
  int jobArtifactsSize;
  int packagesSize;

  ProjectStatistics(
      {this.commits,
      this.storageSize,
      this.repositorySize,
      this.wikiSize,
      this.lfsObjectsSize,
      this.jobArtifactsSize,
      this.packagesSize});

  ProjectStatistics.fromJSON(Map<String, dynamic> data)
      : commits = data['commit_count'],
        storageSize = data['storage_size'],
        repositorySize = data['repository_size'],
        wikiSize = data['wiki_size'],
        lfsObjectsSize = data['lfs_objects_size'],
        jobArtifactsSize = data['job_artifacts_size'],
        packagesSize = data['packages_size'];
}

class AccessPermission {
  int accessLevel;
  int notificationLevel;

  AccessPermission({this.accessLevel, this.notificationLevel});

  AccessPermission.fromJSON(Map<String, dynamic> data)
      : accessLevel = data['access_level'],
        notificationLevel = data['notification_level'];
}

class ProjectPermission {
  AccessPermission projectAccess;
  AccessPermission groupAccess;

  ProjectPermission({this.projectAccess, this.groupAccess});

  ProjectPermission.fromJSON(Map<String, dynamic> data)
      : projectAccess = new AccessPermission.fromJSON(data['project_access']),
        groupAccess = new AccessPermission.fromJSON(data['group_access']);
}

class Project {
  bool simple; // Set by APIClient

  // Simple Fields
  int id;
  String description;
  String defaultBranch;
  String sshURL;
  String httpURL;
  String webURL;
  String readmeURL;
  List<String> tagList;
  String name;
  String nameWithNamespace;
  String path;
  String pathWithNamespace;
  DateTime createdAt;
  DateTime lastActivityAt;
  int forks;
  int stars;
  String avatarURL;

  // Deep Fields;
  Owner owner;
  bool issueEnabled;
  int openIssues;
  bool mergeRequestEnabled;
  bool jobEnabled;
  bool wikiEnabled;
  bool snippetEnabled;
  bool resolveOutdatedDiffDiscussions;
  bool containerRegistryEnabled;
  int creatorid;
  Namespace namespace;
  String importStatus;
  String importError;
  bool sharedRunnerEnabled;
  String runnersToken;
  int ciDefaultGitDepth;
  bool publicJobs;
  List<GroupAccess> sharedWithGroup;
  bool onlyAllowMergeIfPiplineSucceeds;
  bool onlyAllowMergeIfAllDiscussionsAreResolved;
  bool requestAccessEnabled;
  String mergeMethod;
  ProjectStatistics statistics;
  ProjectPermission permissions;
  int approvalsBeforeMerge;
  Project forkedFromProject;

  // Available in details only
  String licenseURL;
  License license;
  String repositoryStorage;

  Project(this.name, this.path,
      {this.id,
      this.description,
      this.defaultBranch,
      this.sshURL,
      this.httpURL,
      this.webURL,
      this.readmeURL,
      this.tagList,
      this.nameWithNamespace,
      this.pathWithNamespace,
      this.createdAt,
      this.lastActivityAt,
      this.forkedFromProject,
      this.forks,
      this.approvalsBeforeMerge,
      this.avatarURL,
      this.ciDefaultGitDepth,
      this.containerRegistryEnabled,
      this.creatorid,
      this.importError,
      this.importStatus,
      this.issueEnabled,
      this.jobEnabled,
      this.mergeMethod,
      this.mergeRequestEnabled,
      this.namespace,
      this.onlyAllowMergeIfAllDiscussionsAreResolved,
      this.onlyAllowMergeIfPiplineSucceeds,
      this.openIssues,
      this.owner,
      this.permissions,
      this.publicJobs,
      this.requestAccessEnabled,
      this.resolveOutdatedDiffDiscussions,
      this.runnersToken,
      this.sharedRunnerEnabled,
      this.sharedWithGroup,
      this.simple,
      this.snippetEnabled,
      this.stars,
      this.statistics,
      this.wikiEnabled});

  Project.fromJSON(Map<String, dynamic> data, [this.simple = true]) {
    id = data['id'];
    description = data['description'];
    defaultBranch = data['default_branch'];
    sshURL = data['ssh_url'];
    webURL = data['web_url'];
    readmeURL = data['readme_url'];
    tagList = List<String>.from(data['tag_list']);
    name = data['name'];
    nameWithNamespace = data['name_with_namespace'];
    path = data['path'];
    pathWithNamespace = data['path_with_namespace'];
    createdAt = DateTime.parse(data['created_at']);
    lastActivityAt = DateTime.parse(data['last_activity_at']);
    forks = data['fork_count'];
    stars = data['star_count'];
    avatarURL = data['avatarURL'];
    if (!this.simple) {
      owner = new Owner.fromJSON(data['owner']);
      issueEnabled = data['issue_enabled'];
      openIssues = data['openIssues'];
      mergeRequestEnabled = data['merge_request_enabled'];
      jobEnabled = data['job_enabled'];
      wikiEnabled = data['wiki_enabled'];
      snippetEnabled = data['snippet_enabled'];
      resolveOutdatedDiffDiscussions =
          data['resolve_outdated_diff_discussions'];
      containerRegistryEnabled = data['container_registry_enabled'];
      creatorid = data['creator_id'];
      namespace = new Namespace.fromJSON(data['namespace']);
      importStatus = data['import_status'];
      importError = data['import_error'];
      sharedRunnerEnabled = data['shared_runner_enabled'];
      runnersToken = data['runners_token'];
      ciDefaultGitDepth = data['ci_default_git_depth'];
      publicJobs = data['public_jobs'];
      sharedWithGroup = List<GroupAccess>.of(
          (data['shared_with_group'] as Iterable)
              .map((item) => new GroupAccess.fromJSON(item)));
      onlyAllowMergeIfAllDiscussionsAreResolved =
          data['only_allow_merge_if_all_discussions_are_resolved'];
      onlyAllowMergeIfPiplineSucceeds =
          data['only_allow_merge_if_pipeline_succeeds'];
      requestAccessEnabled = data['request_access_enabled'];
      mergeMethod = data['merge_method'];
      statistics = new ProjectStatistics.fromJSON(data['statistics']);
      permissions = new ProjectPermission.fromJSON(data['permissions']);
      approvalsBeforeMerge = data['approvals_before_merege'];
      forkedFromProject = data['forked_from_prject'] ??
          new Project.fromJSON(data['forked_from_project'], true);
      licenseURL = data['license_url'];
      license = new License.fromJSON(data['license']);
      repositoryStorage = data['repository_storage'];
    }
  }
}
